==> tecfy_corev2_package-1.1.30.tar.gz: lib/models/project/connection.model.dart <==
part of tecfy_corev2_client_package;

class Connection {
  String? id;
  late bool isCloud;
  late String name;
  String? version;
  DateTime? lastActive;
  Color? color;
  String get colorString => color?.toHexString() ?? Colors.black.toHexString();
  set colorString(String? s) =>
      color = (s?.toColor(Colors.black) ?? Colors.black);
  late String server;
  late bool isHTTPS;
  ConnectionStatus status = ConnectionStatus.unknown;
  late bool active;
  late int sortId;
  String? errorMessage;
  Connection(
      {this.id,
      this.sortId = 1,
      this.isCloud = true,
      required this.name,
      this.color = Colors.black,
      required this.server,
      this.status = ConnectionStatus.unknown,
      this.active = true,
      this.isHTTPS = false}) {
    if (id == null) id = Uuid().v4().replaceAll('-', '');
  }

  String get apiUrl => '${isHTTPS ? 'https' : 'http'}://$server/api/';
  String get wsURL => '${isHTTPS ? 'wss' : 'ws'}://$server/ws';

  Connection.fromJson(Map<String, dynamic> row) {
    id = row['_id'] ?? Uuid().v4().replaceAll('-', '');
    sortId = row['sortId'] ?? 1;
    name = row['name'] ?? '';
    isCloud = row['isCloud'] ?? true;
    version = row['version'];
    lastActive = (row['lastActive'] == null || row['lastActive'] == 0)
        ? null
        : DateTime.fromMillisecondsSinceEpoch(row['lastActive'], isUtc: true);
    colorString = row['colorString'];
    server = row['server'];
    isHTTPS = row['isHTTPS'] ?? false;
    active = row['active'] ?? true;
  }

  Map<String, dynamic> toJson() {
    return {
      'id': id ?? Uuid().v4().replaceAll('-', ''),
      'name': name,
      'sortId': sortId,
      'isCloud': isCloud,
      'version': version,
      'lastActive': lastActive?.millisecondsSinceEpoch ?? 0,
      'colorString': colorString,
      'server': server,
      'isHTTPS': isHTTPS,
      'active': active
    };
  }
}

enum ConnectionStatus {
  unknown,
  connected,
  disconnected,
}

enum ConnectionType {
  local,
  cloud,
}

==> tecfy_corev2_package-1.1.35.tar.gz: lib/models/project/connection.model.dart <==
part of tecfy_corev2_client_package;

class Connection {
  String? id;
  late bool isCloud;
  late String name;
  String? version;
  DateTime? lastActive;
  Color? color;
  String get colorString => color?.toHexString() ?? Colors.black.toHexString();
  set colorString(String? s) =>
      color = (s?.toColorEx(Colors.black) ?? Colors.black);
  late String server;
  late bool isHTTPS;
  ConnectionStatus status = ConnectionStatus.unknown;
  late bool active;
  late int sortId;
  String? errorMessage;
  Connection(
      {this.id,
      this.sortId = 1,
      this.isCloud = true,
      required this.name,
      this.color = Colors.black,
      required this.server,
      this.status = ConnectionStatus.unknown,
      this.active = true,
      this.isHTTPS = false}) {
    if (id == null) id = Uuid().v4().replaceAll('-', '');
  }

  String get apiUrl => '${isHTTPS ? 'https' : 'http'}://$server/api/';
  String get wsURL => '${isHTTPS ? 'wss' : 'ws'}://$server/ws';

  Connection.fromJson(Map<String, dynamic> row) {
    id = row['_id'] ?? Uuid().v4().replaceAll('-', '');
    sortId = row['sortId'] ?? 1;
    name = row['name'] ?? '';
    isCloud = row['isCloud'] ?? true;
    version = row['version'];
    lastActive = (row['lastActive'] == null || row['lastActive'] == 0)
        ? null
        : DateTime.fromMillisecondsSinceEpoch(row['lastActive'], isUtc: true);
    colorString = row['colorString'];
    server = row['server'];
    isHTTPS = row['isHTTPS'] ?? false;
    active = row['active'] ?? true;
  }

  Map<String, dynamic> toJson() {
    return {
      'id': id ?? Uuid().v4().replaceAll('-', ''),
      'name': name,
      'sortId': sortId,
      'isCloud': isCloud,
      'version': version,
      'lastActive': lastActive?.millisecondsSinceEpoch ?? 0,
      'colorString': colorString,
      'server': server,
      'isHTTPS': isHTTPS,
      'active': active
    };
  }
}

enum ConnectionStatus {
  unknown,
  connected,
  disconnected,
}

enum ConnectionType {
  local,
  cloud,
}
